@@ -188,7 +188,8 @@ int FuncPredSub(Context* cx, Node* g, List* module, Node* &retn)
 			if ((g->Car()->Eq(mka("obj"))) 
 					|| (g->Car()->Eq(mka("unify")))) {
 				g = g->Val();
-				if (g->Cdr()->Car()->Eq(mka("sys"))) {
+#if 0
+				if (g->Cdr()->Car()->Eq(mka("sys3"))) {
 					int r;
 					int rt = sysmodule(cx, g->Cdr()->Cdr()->Car(),
 							Nil, Nil, 
@@ -215,59 +216,26 @@ int FuncPredSub(Context* cx, Node* g, List* module, Node* &retn)
 					}
 					return 1;
 					
-				} else if (g->Cdr()->Car()->Eq(mka("compiler"))) {
-					int r;
-					int rt = compmodule(cx, g->Cdr()->Cdr()->Car(),
-							Nil, Nil, 
-							module, r);
-					retn = g->Cdr()->Cdr()->Car()->Cdr()->Car()
-									->Val();
-					if (rt) {
-						if (r>0) {
-					    		if (TraceFlag) {
-								PrintNode("compiler module: ", g->Val(), "...success");
-							}
-						} else {
-						    if (TraceFlag) {
-							if (r == 0) {
-								PrintNode("compiler module: ", g->Val(), "...false");
-							} else {	// rval == -1
-								PrintNode("compiler module: ", g->Val(), "...unknown");
-							}
-						    }
-						    return r;
-						}
-					} else {
-						return -1;
+				}
+#endif
+				int r = DoUnify(cx, g,	module);
+
+				retn = g->Cdr()->Cdr()->Car()->Cdr()->Car()
+								->Val();
+				if (r>0) {
+			    		if (TraceFlag) {
+						PrintNode("module: ", g->Val(), "...success");
 					}
-					return 1;
-				} else if (g->Cdr()->Car()->Eq(mka("curses"))) {
-					int r;
-					int rt = cursmodule(cx, g->Cdr()->Cdr()->Car(),
-							Nil, Nil, 
-							module, r);
-					retn = g->Cdr()->Cdr()->Car()->Cdr()->Car()
-									->Val();
-					if (rt) {
-						if (r>0) {
-					    		if (TraceFlag) {
-								PrintNode("curses module: ", g->Val(), "...success");
-							}
-						} else {
-						    if (TraceFlag) {
-							if (r == 0) {
-								PrintNode("curses module: ", g->Val(), "...false");
-							} else {	// rval == -1
-								PrintNode("curses module: ", g->Val(), "...unknown");
-							}
-						    }
-						    return r;
-						}
-					} else {
-						return -1;
+					return r;
+				} else {
+				    if (TraceFlag) {
+					if (r == 0) {
+						PrintNode("module: ", g->Val(), "...false");
+					} else {	// rval == -1
+						PrintNode("module: ", g->Val(), "...unknown");
 					}
-					return 1;
-					
+				    }
+				    return r;
 				}
 			}
 			retncar = retncdr = Nil;
