@@ -34,14 +34,22 @@
 
 static char temppath[MAXPATHLEN];
 
+char lasttemp[MAXPATHLEN] = {0,0};
+FILE* lastfd = NULL;
+
 FILE* MksTemp(char* templ)
 {
+	FILE* fd;
+
 	if(GetTempPath(MAXPATHLEN, temppath)!=0){
 //printf("temppath %s\n", temppath);
 		if(GetTempFileName(temppath, "dtm", 0, templ) != 0){
-		FILE* fd;
 
-		fd = fopen(templ, "w+");
+		strncpy(lasttemp, templ, MAXPATHLEN-1);
+		lasttemp[MAXPATHLEN-1] = 0;
+		lastfd = NULL;
+		
+		lastfd = fd = fopen(templ, "w+b");
 		if(fd != NULL)
 			return fd;
 		}
